@@ -2,27 +2,19 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="pt">
 <context>
-    <name>LxQtCpuLoad</name>
+    <name>LXQtCpuLoad</name>
     <message>
-        <source>Cpu load %1%</source>
-        <translation type="vanished">Carga do cpu %1%</translation>
-    </message>
-    <message>
-        <location filename="../lxqtcpuload.cpp" line="119"/>
+        <location filename="../lxqtcpuload.cpp" line="127"/>
         <source>CPU load %1%</source>
-        <translation type="unfinished"></translation>
+        <translation>Carga do CPU %1%</translation>
     </message>
 </context>
 <context>
-    <name>LxQtCpuLoadConfiguration</name>
-    <message>
-        <source>LxQt Cpu Load settings</source>
-        <translation type="vanished">Definições da Carga do cpu</translation>
-    </message>
+    <name>LXQtCpuLoadConfiguration</name>
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
         <source>CPU Load Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Definições do CPU</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
@@ -37,37 +29,42 @@
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
         <source>Update interval:</source>
-        <translation>Intervalo:</translation>
+        <translation>Intervalo de atualização:</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
         <source>sec</source>
-        <translation>seg.</translation>
+        <translation>seg</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
         <source>Bar orientation:</source>
         <translation>Orientação da barra:</translation>
     </message>
+    <message>
+        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
+        <source>Bar width:</source>
+        <translation>Largura da barra:</translation>
+    </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
         <source>Bottom up</source>
-        <translation>De baixo para cima</translation>
+        <translation>Baixo -&gt; Cima</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
         <source>Top down</source>
-        <translation>De cima para baixo</translation>
+        <translation>Cima -&gt; Baixo</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
         <source>Left to right</source>
-        <translation>Da esquerda para a direita</translation>
+        <translation>Esquerda -&gt; Direita</translation>
     </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
         <source>Right to left</source>
-        <translation>Da direita para a esquerda</translation>
+        <translation>Direita -&gt; Esquerda</translation>
     </message>
 </context>
 </TS>
