@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="tr">
 <context>
-    <name>LxQtQuickLaunch</name>
+    <name>LXQtQuickLaunch</name>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
@@ -14,26 +14,26 @@
         <translation>Şimdilik &apos;%1&apos; dosyası/bağlantısı Hızlı Başlatıcı&apos; ya eklenemiyor</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="319"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Uygulama simgesini buraya bırakın</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
         <translation>Sola kaydır</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
         <translation>Sağa kaydır</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
         <translation>Hızlı başlatıcıdan kaldır</translation>
     </message>
